Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterQuizServiceServer(s grpc.ServiceRegistrar, srv QuizServiceServer)
- type CreateQuizRequest
- func (*CreateQuizRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateQuizRequest) GetCreatedBy() string
- func (x *CreateQuizRequest) GetDescription() string
- func (x *CreateQuizRequest) GetStatus() string
- func (x *CreateQuizRequest) GetTitle() string
- func (*CreateQuizRequest) ProtoMessage()
- func (x *CreateQuizRequest) ProtoReflect() protoreflect.Message
- func (x *CreateQuizRequest) Reset()
- func (x *CreateQuizRequest) String() string
- type CreateQuizResponse
- func (*CreateQuizResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateQuizResponse) GetCreatedId() string
- func (*CreateQuizResponse) ProtoMessage()
- func (x *CreateQuizResponse) ProtoReflect() protoreflect.Message
- func (x *CreateQuizResponse) Reset()
- func (x *CreateQuizResponse) String() string
- type DeleteQuizRequest
- type DeleteQuizResponse
- func (*DeleteQuizResponse) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteQuizResponse) GetDeletedId() string
- func (*DeleteQuizResponse) ProtoMessage()
- func (x *DeleteQuizResponse) ProtoReflect() protoreflect.Message
- func (x *DeleteQuizResponse) Reset()
- func (x *DeleteQuizResponse) String() string
- type GetQuizRequest
- type GetQuizResponse
- func (*GetQuizResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetQuizResponse) GetCreatedAt() *timestamppb.Timestamp
- func (x *GetQuizResponse) GetCreatedBy() string
- func (x *GetQuizResponse) GetDescription() string
- func (x *GetQuizResponse) GetId() string
- func (x *GetQuizResponse) GetQuestions() []*v1.GetQuestionResponse
- func (x *GetQuizResponse) GetStatus() string
- func (x *GetQuizResponse) GetTitle() string
- func (x *GetQuizResponse) GetTotalPoints() float64
- func (x *GetQuizResponse) GetUpdatedAt() *timestamppb.Timestamp
- func (*GetQuizResponse) ProtoMessage()
- func (x *GetQuizResponse) ProtoReflect() protoreflect.Message
- func (x *GetQuizResponse) Reset()
- func (x *GetQuizResponse) String() string
- type QuizServiceClient
- type QuizServiceServer
- type UnimplementedQuizServiceServer
- func (UnimplementedQuizServiceServer) CreateQuiz(context.Context, *CreateQuizRequest) (*CreateQuizResponse, error)
- func (UnimplementedQuizServiceServer) DeleteQuiz(context.Context, *DeleteQuizRequest) (*DeleteQuizResponse, error)
- func (UnimplementedQuizServiceServer) GetQuizById(context.Context, *GetQuizRequest) (*GetQuizResponse, error)
- func (UnimplementedQuizServiceServer) UpdateQuiz(context.Context, *UpdateQuizRequest) (*UpdateQuizResponse, error)
- type UnsafeQuizServiceServer
- type UpdateQuizRequest
- type UpdateQuizResponse
- func (*UpdateQuizResponse) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateQuizResponse) GetUpdatedId() string
- func (*UpdateQuizResponse) ProtoMessage()
- func (x *UpdateQuizResponse) ProtoReflect() protoreflect.Message
- func (x *UpdateQuizResponse) Reset()
- func (x *UpdateQuizResponse) String() string
Constants ¶
const ( QuizService_CreateQuiz_FullMethodName = "/quiz.service.frontend.quiz.v1.QuizService/CreateQuiz" QuizService_GetQuizById_FullMethodName = "/quiz.service.frontend.quiz.v1.QuizService/GetQuizById" QuizService_UpdateQuiz_FullMethodName = "/quiz.service.frontend.quiz.v1.QuizService/UpdateQuiz" QuizService_DeleteQuiz_FullMethodName = "/quiz.service.frontend.quiz.v1.QuizService/DeleteQuiz" )
Variables ¶
var File_quiz_service_service_frontend_quiz_v1_quiz_proto protoreflect.FileDescriptor
var QuizService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "quiz.service.frontend.quiz.v1.QuizService", HandlerType: (*QuizServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateQuiz", Handler: _QuizService_CreateQuiz_Handler, }, { MethodName: "GetQuizById", Handler: _QuizService_GetQuizById_Handler, }, { MethodName: "UpdateQuiz", Handler: _QuizService_UpdateQuiz_Handler, }, { MethodName: "DeleteQuiz", Handler: _QuizService_DeleteQuiz_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "quiz-service/service/frontend/quiz/v1/quiz.proto", }
QuizService_ServiceDesc is the grpc.ServiceDesc for QuizService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterQuizServiceServer ¶
func RegisterQuizServiceServer(s grpc.ServiceRegistrar, srv QuizServiceServer)
Types ¶
type CreateQuizRequest ¶
type CreateQuizRequest struct {
Title string `protobuf:"bytes,1,opt,name=title,proto3" json:"title,omitempty"`
Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
CreatedBy string `protobuf:"bytes,3,opt,name=created_by,json=createdBy,proto3" json:"created_by,omitempty"`
Status string `protobuf:"bytes,4,opt,name=status,proto3" json:"status,omitempty"`
// contains filtered or unexported fields
}
func (*CreateQuizRequest) Descriptor
deprecated
func (*CreateQuizRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateQuizRequest.ProtoReflect.Descriptor instead.
func (*CreateQuizRequest) GetCreatedBy ¶
func (x *CreateQuizRequest) GetCreatedBy() string
func (*CreateQuizRequest) GetDescription ¶
func (x *CreateQuizRequest) GetDescription() string
func (*CreateQuizRequest) GetStatus ¶
func (x *CreateQuizRequest) GetStatus() string
func (*CreateQuizRequest) GetTitle ¶
func (x *CreateQuizRequest) GetTitle() string
func (*CreateQuizRequest) ProtoMessage ¶
func (*CreateQuizRequest) ProtoMessage()
func (*CreateQuizRequest) ProtoReflect ¶
func (x *CreateQuizRequest) ProtoReflect() protoreflect.Message
func (*CreateQuizRequest) Reset ¶
func (x *CreateQuizRequest) Reset()
func (*CreateQuizRequest) String ¶
func (x *CreateQuizRequest) String() string
type CreateQuizResponse ¶
type CreateQuizResponse struct {
CreatedId string `protobuf:"bytes,1,opt,name=created_id,json=createdId,proto3" json:"created_id,omitempty"`
// contains filtered or unexported fields
}
func (*CreateQuizResponse) Descriptor
deprecated
func (*CreateQuizResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateQuizResponse.ProtoReflect.Descriptor instead.
func (*CreateQuizResponse) GetCreatedId ¶
func (x *CreateQuizResponse) GetCreatedId() string
func (*CreateQuizResponse) ProtoMessage ¶
func (*CreateQuizResponse) ProtoMessage()
func (*CreateQuizResponse) ProtoReflect ¶
func (x *CreateQuizResponse) ProtoReflect() protoreflect.Message
func (*CreateQuizResponse) Reset ¶
func (x *CreateQuizResponse) Reset()
func (*CreateQuizResponse) String ¶
func (x *CreateQuizResponse) String() string
type DeleteQuizRequest ¶
type DeleteQuizRequest struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteQuizRequest) Descriptor
deprecated
func (*DeleteQuizRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteQuizRequest.ProtoReflect.Descriptor instead.
func (*DeleteQuizRequest) GetId ¶
func (x *DeleteQuizRequest) GetId() string
func (*DeleteQuizRequest) ProtoMessage ¶
func (*DeleteQuizRequest) ProtoMessage()
func (*DeleteQuizRequest) ProtoReflect ¶
func (x *DeleteQuizRequest) ProtoReflect() protoreflect.Message
func (*DeleteQuizRequest) Reset ¶
func (x *DeleteQuizRequest) Reset()
func (*DeleteQuizRequest) String ¶
func (x *DeleteQuizRequest) String() string
type DeleteQuizResponse ¶
type DeleteQuizResponse struct {
DeletedId string `protobuf:"bytes,1,opt,name=deleted_id,json=deletedId,proto3" json:"deleted_id,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteQuizResponse) Descriptor
deprecated
func (*DeleteQuizResponse) Descriptor() ([]byte, []int)
Deprecated: Use DeleteQuizResponse.ProtoReflect.Descriptor instead.
func (*DeleteQuizResponse) GetDeletedId ¶
func (x *DeleteQuizResponse) GetDeletedId() string
func (*DeleteQuizResponse) ProtoMessage ¶
func (*DeleteQuizResponse) ProtoMessage()
func (*DeleteQuizResponse) ProtoReflect ¶
func (x *DeleteQuizResponse) ProtoReflect() protoreflect.Message
func (*DeleteQuizResponse) Reset ¶
func (x *DeleteQuizResponse) Reset()
func (*DeleteQuizResponse) String ¶
func (x *DeleteQuizResponse) String() string
type GetQuizRequest ¶
type GetQuizRequest struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
func (*GetQuizRequest) Descriptor
deprecated
func (*GetQuizRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetQuizRequest.ProtoReflect.Descriptor instead.
func (*GetQuizRequest) GetId ¶
func (x *GetQuizRequest) GetId() string
func (*GetQuizRequest) ProtoMessage ¶
func (*GetQuizRequest) ProtoMessage()
func (*GetQuizRequest) ProtoReflect ¶
func (x *GetQuizRequest) ProtoReflect() protoreflect.Message
func (*GetQuizRequest) Reset ¶
func (x *GetQuizRequest) Reset()
func (*GetQuizRequest) String ¶
func (x *GetQuizRequest) String() string
type GetQuizResponse ¶
type GetQuizResponse struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Title string `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
CreatedBy string `protobuf:"bytes,4,opt,name=created_by,json=createdBy,proto3" json:"created_by,omitempty"`
Status string `protobuf:"bytes,5,opt,name=status,proto3" json:"status,omitempty"`
TotalPoints float64 `protobuf:"fixed64,6,opt,name=total_points,json=totalPoints,proto3" json:"total_points,omitempty"`
Questions []*v1.GetQuestionResponse `protobuf:"bytes,7,rep,name=questions,proto3" json:"questions,omitempty"`
CreatedAt *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
UpdatedAt *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
// contains filtered or unexported fields
}
func (*GetQuizResponse) Descriptor
deprecated
func (*GetQuizResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetQuizResponse.ProtoReflect.Descriptor instead.
func (*GetQuizResponse) GetCreatedAt ¶
func (x *GetQuizResponse) GetCreatedAt() *timestamppb.Timestamp
func (*GetQuizResponse) GetCreatedBy ¶
func (x *GetQuizResponse) GetCreatedBy() string
func (*GetQuizResponse) GetDescription ¶
func (x *GetQuizResponse) GetDescription() string
func (*GetQuizResponse) GetId ¶
func (x *GetQuizResponse) GetId() string
func (*GetQuizResponse) GetQuestions ¶
func (x *GetQuizResponse) GetQuestions() []*v1.GetQuestionResponse
func (*GetQuizResponse) GetStatus ¶
func (x *GetQuizResponse) GetStatus() string
func (*GetQuizResponse) GetTitle ¶
func (x *GetQuizResponse) GetTitle() string
func (*GetQuizResponse) GetTotalPoints ¶
func (x *GetQuizResponse) GetTotalPoints() float64
func (*GetQuizResponse) GetUpdatedAt ¶
func (x *GetQuizResponse) GetUpdatedAt() *timestamppb.Timestamp
func (*GetQuizResponse) ProtoMessage ¶
func (*GetQuizResponse) ProtoMessage()
func (*GetQuizResponse) ProtoReflect ¶
func (x *GetQuizResponse) ProtoReflect() protoreflect.Message
func (*GetQuizResponse) Reset ¶
func (x *GetQuizResponse) Reset()
func (*GetQuizResponse) String ¶
func (x *GetQuizResponse) String() string
type QuizServiceClient ¶
type QuizServiceClient interface {
CreateQuiz(ctx context.Context, in *CreateQuizRequest, opts ...grpc.CallOption) (*CreateQuizResponse, error)
GetQuizById(ctx context.Context, in *GetQuizRequest, opts ...grpc.CallOption) (*GetQuizResponse, error)
UpdateQuiz(ctx context.Context, in *UpdateQuizRequest, opts ...grpc.CallOption) (*UpdateQuizResponse, error)
DeleteQuiz(ctx context.Context, in *DeleteQuizRequest, opts ...grpc.CallOption) (*DeleteQuizResponse, error)
}
QuizServiceClient is the client API for QuizService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewQuizServiceClient ¶
func NewQuizServiceClient(cc grpc.ClientConnInterface) QuizServiceClient
type QuizServiceServer ¶
type QuizServiceServer interface {
CreateQuiz(context.Context, *CreateQuizRequest) (*CreateQuizResponse, error)
GetQuizById(context.Context, *GetQuizRequest) (*GetQuizResponse, error)
UpdateQuiz(context.Context, *UpdateQuizRequest) (*UpdateQuizResponse, error)
DeleteQuiz(context.Context, *DeleteQuizRequest) (*DeleteQuizResponse, error)
// contains filtered or unexported methods
}
QuizServiceServer is the server API for QuizService service. All implementations must embed UnimplementedQuizServiceServer for forward compatibility.
type UnimplementedQuizServiceServer ¶
type UnimplementedQuizServiceServer struct{}
UnimplementedQuizServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedQuizServiceServer) CreateQuiz ¶
func (UnimplementedQuizServiceServer) CreateQuiz(context.Context, *CreateQuizRequest) (*CreateQuizResponse, error)
func (UnimplementedQuizServiceServer) DeleteQuiz ¶
func (UnimplementedQuizServiceServer) DeleteQuiz(context.Context, *DeleteQuizRequest) (*DeleteQuizResponse, error)
func (UnimplementedQuizServiceServer) GetQuizById ¶
func (UnimplementedQuizServiceServer) GetQuizById(context.Context, *GetQuizRequest) (*GetQuizResponse, error)
func (UnimplementedQuizServiceServer) UpdateQuiz ¶
func (UnimplementedQuizServiceServer) UpdateQuiz(context.Context, *UpdateQuizRequest) (*UpdateQuizResponse, error)
type UnsafeQuizServiceServer ¶
type UnsafeQuizServiceServer interface {
// contains filtered or unexported methods
}
UnsafeQuizServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to QuizServiceServer will result in compilation errors.
type UpdateQuizRequest ¶
type UpdateQuizRequest struct {
Quiz *v11.Quiz `protobuf:"bytes,1,opt,name=quiz,proto3" json:"quiz,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateQuizRequest) Descriptor
deprecated
func (*UpdateQuizRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateQuizRequest.ProtoReflect.Descriptor instead.
func (*UpdateQuizRequest) GetQuiz ¶
func (x *UpdateQuizRequest) GetQuiz() *v11.Quiz
func (*UpdateQuizRequest) ProtoMessage ¶
func (*UpdateQuizRequest) ProtoMessage()
func (*UpdateQuizRequest) ProtoReflect ¶
func (x *UpdateQuizRequest) ProtoReflect() protoreflect.Message
func (*UpdateQuizRequest) Reset ¶
func (x *UpdateQuizRequest) Reset()
func (*UpdateQuizRequest) String ¶
func (x *UpdateQuizRequest) String() string
type UpdateQuizResponse ¶
type UpdateQuizResponse struct {
UpdatedId string `protobuf:"bytes,1,opt,name=updated_id,json=updatedId,proto3" json:"updated_id,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateQuizResponse) Descriptor
deprecated
func (*UpdateQuizResponse) Descriptor() ([]byte, []int)
Deprecated: Use UpdateQuizResponse.ProtoReflect.Descriptor instead.
func (*UpdateQuizResponse) GetUpdatedId ¶
func (x *UpdateQuizResponse) GetUpdatedId() string
func (*UpdateQuizResponse) ProtoMessage ¶
func (*UpdateQuizResponse) ProtoMessage()
func (*UpdateQuizResponse) ProtoReflect ¶
func (x *UpdateQuizResponse) ProtoReflect() protoreflect.Message
func (*UpdateQuizResponse) Reset ¶
func (x *UpdateQuizResponse) Reset()
func (*UpdateQuizResponse) String ¶
func (x *UpdateQuizResponse) String() string